@@ -1,16 +1,16 @@
-package Helios::Logger::LoggingError;
+package Helios::Error::LoggingError;
 
 use base qw(Helios::Error::BaseError);
 
-our $VERSION = '2.30_5071';
+our $VERSION = '2.31_0231';
 
 1;
 __END__;
 
 =head1 NAME
 
-Helios::Error::LoggingError - exception class for Helios indicating a logging 
-subsystem error occurred
+Helios::Error::LoggingError - exception class for Helios indicating an error 
+occurred in the logging subsystem
 
 =head1 SYNOPSIS
 
@@ -18,7 +18,9 @@ subsystem error occurred
 
  =head1 DESCRIPTION
 
-#[]
+Helios::Error::LoggingError exceptions indicate a problem with the Helios 
+logging subsystem.  They are designed to be thrown by Helios::Logger 
+subclasses like Helios::Logger::Internal, HeliosX::Logger::Syslog, etc.
 
 =head1 SEE ALSO
 
@@ -26,11 +28,11 @@ L<Helios::Service>
 
 =head1 AUTHOR
 
-Andrew Johnson, E<lt>lajandy@cpan.orgE<gt>
+Andrew Johnson, E<lt>lajandy at cpan dotorgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-11 Andrew Johnson.
+Copyright (C) 2008-12 Andrew Johnson.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.0 or,
